@@ -247,6 +247,14 @@ impl TryFrom<&String> for Message {
   }
 }
 
+impl TryFrom<&str> for Message {
+  type Error = MessageBuilderError;
+
+  fn try_from(message: &str) -> anyhow::Result<Self, Self::Error> {
+    MessageBuilder::default().text(message).build()
+  }
+}
+
 impl TryFrom<ToolComponent> for Tool {
   type Error = ToolBuilderError;
 
